namespace GammaJul.MediaPortal.Subtitles.SousTitresEu {
	
	/// <summary>
	/// Represents information about a language.
	/// </summary>
	public sealed class LanguageInfo {
		private readonly string _isoCode;
		private readonly string _twoLettersCode;
		private readonly string _versionAbbreviation;

		/// <summary>
		/// Returns the three letters ISO code.
		/// </summary>
		public string IsoCode {
			get { return _isoCode; }
		}

		/// <summary>
		/// Returns the two letters code.
		/// </summary>
		public string TwoLettersCode {
			get { return _twoLettersCode; }
		}

		/// <summary>
		/// Returns a version abbreviation commonly used on french subtitles websites (eg: VF).
		/// </summary>
		public string VersionAbbreviation {
			get { return _versionAbbreviation; }
		}

		/// <summary>
		/// Initialise a new instance of <see cref="LanguageInfo"/>.
		/// </summary>
		/// <param name="isoCode">Three letters ISO code</param>
		/// <param name="twoLetterCode">Two letters code</param>
		/// <param name="versionAbbreviation">Version abbreviation commonly used on french subtitles websites.</param>
		public LanguageInfo(string isoCode, string twoLetterCode, string versionAbbreviation) {
			_isoCode = isoCode;
			_twoLettersCode = twoLetterCode;
			_versionAbbreviation = versionAbbreviation;
		}
	}

}