using System;
using System.Collections.ObjectModel;

namespace GammaJul.MediaPortal.Subtitles.SousTitresEu {
	
	/// <summary>
	/// Contains information about all supported languages on sous-titres.eu.
	/// </summary>
	public static class LanguageInfos {
		private static readonly LanguageInfo _english = new LanguageInfo("eng", "en", "VO");
		private static readonly LanguageInfo _french = new LanguageInfo("fre", "fr", "VF");
		private static readonly ReadOnlyCollection<LanguageInfo> _all = Array.AsReadOnly(new[] { _english, _french });

		/// <summary>
		/// Returns the list of all supported languages.
		/// </summary>
		public static ReadOnlyCollection<LanguageInfo> All {
			get { return _all; }
		}

		/// <summary>
		/// Returns English language information.
		/// </summary>
		public static LanguageInfo English {
			get { return _english; }
		}

		/// <summary>
		/// Returns French language information.
		/// </summary>
		public static LanguageInfo French {
			get { return _french; }
		}

	}

}